@@ -35,7 +35,7 @@ class Conversation::ConversationPrivate
   public:
       ConversationPrivate()
       {
-          messages = 0;
+          messages = nullptr;
           delegated = false;
           valid = false;
           isGroupChat = false;
@@ -48,6 +48,7 @@ class Conversation::ConversationPrivate
     bool valid;
     Tp::AccountPtr account;
     QTimer *pausedStateTimer;
+    KPeople::PersonData *personData;
     // May be null for group chats.
     KTp::ContactPtr targetContact;
     bool isGroupChat;
@@ -60,6 +61,8 @@ Conversation::Conversation(const Tp::TextChannelPtr &channel,
         d (new ConversationPrivate)
 {
     qCDebug(KTP_DECLARATIVE);
+    d->valid = false;
+    d->isGroupChat = false;
 
     d->account = account;
     connect(d->account.data(), SIGNAL(connectionChanged(Tp::ConnectionPtr)), SLOT(onAccountConnectionChanged(Tp::ConnectionPtr)));
@@ -76,18 +79,32 @@ Conversation::Conversation(const Tp::TextChannelPtr &channel,
     connect(d->pausedStateTimer, SIGNAL(timeout()), this, SLOT(onChatPausedTimerExpired()));
 }
 
-Conversation::Conversation(QObject *parent)
+Conversation::Conversation(const QString &contactId,
+                           const Tp::AccountPtr &account,
+                           QObject *parent)
     : QObject(parent),
       d(new ConversationPrivate)
 {
+    d->valid = true;
+    d->isGroupChat = false;
+    d->account = account;
+    d->personData = new KPeople::PersonData(QStringLiteral("ktp://") + d->account->objectPath().mid(35) + QStringLiteral("?") + contactId);
+
+    d->messages = new MessagesModel(account, this);
+    connect(d->messages, &MessagesModel::unreadCountChanged, this, &Conversation::unreadMessagesChanged);
+    connect(d->messages, &MessagesModel::lastMessageChanged, this, &Conversation::lastMessageChanged);
+    d->messages->setContactData(contactId, d->personData->name());
+
+    Q_EMIT avatarChanged();
+    Q_EMIT titleChanged();
+    Q_EMIT presenceIconChanged();
+    Q_EMIT validityChanged(d->valid);
 }
 
 void Conversation::setTextChannel(const Tp::TextChannelPtr &channel)
 {
-    if (!d->messages) {
-        d->messages = new MessagesModel(d->account, this);
-        connect(d->messages, &MessagesModel::unreadCountChanged, this, &Conversation::unreadMessagesChanged);
-        connect(d->messages, &MessagesModel::lastMessageChanged, this, &Conversation::lastMessageChanged);
+    if (d->messages->account().isNull()) {
+        d->messages->setAccount(d->account);
     }
     if (d->messages->textChannel() != channel) {
         d->messages->setTextChannel(channel);
@@ -95,11 +112,14 @@ void Conversation::setTextChannel(const Tp::TextChannelPtr &channel)
         connect(channel.data(), SIGNAL(invalidated(Tp::DBusProxy*,QString,QString)),
                 SLOT(onChannelInvalidated(Tp::DBusProxy*,QString,QString)));
 
+        connect(channel.data(), &Tp::TextChannel::chatStateChanged, this, &Conversation::contactTypingChanged);
+
         if (channel->targetContact().isNull()) {
             d->isGroupChat = true;
         } else {
             d->isGroupChat = false;
             d->targetContact = KTp::ContactPtr::qObjectCast(channel->targetContact());
+            d->personData = new KPeople::PersonData(QStringLiteral("ktp://") + d->account->objectPath().mid(35) + QStringLiteral("?") + d->targetContact->id());
 
             connect(d->targetContact.constData(), SIGNAL(aliasChanged(QString)), SIGNAL(titleChanged()));
             connect(d->targetContact.constData(), SIGNAL(presenceChanged(Tp::Presence)), SIGNAL(presenceIconChanged()));
@@ -128,11 +148,9 @@ QString Conversation::title() const
     if (d->isGroupChat) {
         QString roomName = textChannel()->targetId();
         return roomName.left(roomName.indexOf(QLatin1Char('@')));
-    } else if (!d->targetContact.isNull()) {
-        return d->targetContact->alias();
+    } else {
+        return d->personData->name();
     }
-
-    return QString();
 }
 
 QIcon Conversation::presenceIcon() const
@@ -183,12 +201,7 @@ Tp::Account* Conversation::accountObject() const
         return d->account.data();
     }
 
-    return 0;
-}
-
-void Conversation::setAccount(const Tp::AccountPtr &account)
-{
-    d->account = account;
+    return nullptr;
 }
 
 bool Conversation::isValid() const
@@ -275,7 +288,9 @@ Conversation::~Conversation()
 {
     qCDebug(KTP_DECLARATIVE);
     //if we are not handling the channel do nothing.
-    if (!d->delegated) {
+    // d->messages is valid here (destroyed in a deeper base class destructor)
+    // but the textChannel actually can be invalid.
+    if (!d->delegated && !d->messages->textChannel().isNull()) {
         d->messages->textChannel()->requestClose();
     }
     delete d;
@@ -289,3 +304,26 @@ bool Conversation::hasUnreadMessages() const
 
     return false;
 }
+
+KPeople::PersonData* Conversation::personData() const
+{
+    return d->personData;
+}
+
+bool Conversation::isContactTyping() const
+{
+    if (d->messages->textChannel()) {
+        return d->messages->textChannel()->chatState(d->targetContact) == Tp::ChannelChatStateComposing;
+    }
+
+    return false;
+}
+
+bool Conversation::canSendMessages() const
+{
+    if (d->messages && d->messages->textChannel()) {
+        return true;
+    }
+
+    return false;
+}
