@@ -33,8 +33,8 @@ class PendingTpLoggerDates : public KTp::PendingLoggerDates
   public:
     explicit PendingTpLoggerDates(const Tp::AccountPtr &account,
                                   const KTp::LogEntity &entity,
-                                  QObject *parent = 0);
-    virtual ~PendingTpLoggerDates();
+                                  QObject *parent = nullptr);
+    ~PendingTpLoggerDates() override;
 
   private Q_SLOTS:
     void datesRetrieved(Tpl::PendingOperation *op);
