@@ -34,8 +34,8 @@ class PendingTpLoggerLogs : public KTp::PendingLoggerLogs
     explicit PendingTpLoggerLogs(const Tp::AccountPtr &account,
                                  const KTp::LogEntity &entity,
                                  const QDate &date,
-                                 QObject *parent = 0);
-    virtual ~PendingTpLoggerLogs();
+                                 QObject *parent = nullptr);
+    ~PendingTpLoggerLogs() override;
 
   private Q_SLOTS:
     void logsRetrieved(Tpl::PendingOperation *op);
